==> kmuddy-0.7.1.tar.gz: kmuddy-0.7.1/kmuddy/dialogs/cdirlist.cpp <==
/***************************************************************************
                          cdirlist.cpp  -  pick a list of directories
                             -------------------
    begin                : So apr 12 2003
    copyright            : (C) 2003 by Tomas Mecir
    email                : kmuddy@host.sk
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#include "cdirlist.h"

#include <qlayout.h>
#include <qlistbox.h>
#include <kpushbutton.h>

#include <kapplication.h>
#include <kfiledialog.h>
#include <kiconloader.h>
#include <klocale.h>

cDirList::cDirList (QWidget *parent, const char *name ) :
    QWidget(parent,name)
{
  //prepare layout
  QGridLayout *layout = new QGridLayout (this, 5, 2);

  //create all widgets
  listbox = new QListBox (this);
  KIconLoader *icons = (KApplication::kApplication())->iconLoader ();
  btadd = new KPushButton (i18n ("&Add..."), this);
  btdel = new KPushButton (i18n ("Delete"), this);
  btup = new KPushButton (icons->loadIcon ("up", KIcon::Small),
        i18n ("Move &up"), this);
  btdown = new KPushButton (icons->loadIcon ("down", KIcon::Small),
        i18n ("Move &down"), this);

  //add widgets to layout
  layout->setSpacing (10);
  layout->setRowStretch (4, 10);
  layout->addMultiCellWidget (listbox, 0, 4, 0, 0);
  layout->addWidget (btadd, 0, 1);
  layout->addWidget (btdel, 1, 1);
  layout->addWidget (btup, 2, 1);
  layout->addWidget (btdown, 3, 1);
  
  //establish connections
  connect (btadd, SIGNAL (clicked ()), this, SLOT (addEntry ()));
  connect (btdel, SIGNAL (clicked ()), this, SLOT (removeEntry ()));
  connect (btup, SIGNAL (clicked ()), this, SLOT (moveEntryUp ()));
  connect (btdown, SIGNAL (clicked ()), this, SLOT (moveEntryDown ()));
  
  //update our contents
  update ();
}

cDirList::~cDirList ()
{

}

void cDirList::setDirList (const QStringList &dlist)
{
  dirlist = dlist;
  update ();
}

void cDirList::addEntry ()
{
  QString dirName = KFileDialog::getExistingDirectory (QString::null, this, i18n ("Choose sound directory"));
  if (dirName != QString::null)
  {
    dirlist.append (dirName);
    update();
  }
}

void cDirList::removeEntry ()
{
  int item = listbox->currentItem ();
  if (item == -1)  //nothing selected
    return;
  //find it
  QStringList::iterator it = dirlist.at (item);
  //kill it
  dirlist.erase (it);
  update ();    
}

void cDirList::moveEntryUp ()
{
  int item = listbox->currentItem ();
  if (item == -1)  //nothing selected
    return;
  if (item == 0)  //first item
    return;
  QStringList::iterator it = dirlist.at (item);
  QString text = *it;
  //it2 will point at previous item
  QStringList::iterator it2 = it;
  it2--;
  //erase that item
  dirlist.erase (it);
  //and insert it before previous item
  dirlist.insert (it2, text);
  update ();
  listbox->setCurrentItem (item - 1);
}

void cDirList::moveEntryDown ()
{
  int item = listbox->currentItem ();
  if (item == -1)  //nothing selected
    return;
  if (item == dirlist.count() - 1) //last item
    return;
  QStringList::iterator it = dirlist.at (item);
  QString text = *it;
  //erase that item, make it point to next item
  it = dirlist.erase (it);
  //and insert it after that item
  dirlist.insert (++it, text);
  update ();
  listbox->setCurrentItem (item + 1);
}

void cDirList::update ()
{
  int item = listbox->currentItem ();
  listbox->clear ();
  listbox->insertStringList (dirlist);
  if (item != -1)
    listbox->setCurrentItem (item);
}

==> kmuddy-0.8.tar.gz: kmuddy-0.8/kmuddy/dialogs/cdirlist.cpp <==
/***************************************************************************
                          cdirlist.cpp  -  pick a list of directories
                             -------------------
    begin                : So apr 12 2003
    copyright            : (C) 2003 by Tomas Mecir
    email                : kmuddy@kmuddy.net
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#include "cdirlist.h"

#include <qlayout.h>
#include <qlistbox.h>
#include <kpushbutton.h>

#include <kapplication.h>
#include <kfiledialog.h>
#include <kiconloader.h>
#include <klocale.h>

cDirList::cDirList (QWidget *parent, const char *name ) :
    QWidget(parent,name)
{
  //prepare layout
  QGridLayout *layout = new QGridLayout (this, 5, 2);

  //create all widgets
  listbox = new QListBox (this);
  KIconLoader *icons = (KApplication::kApplication())->iconLoader ();
  btadd = new KPushButton (i18n ("&Add..."), this);
  btdel = new KPushButton (i18n ("Delete"), this);
  btup = new KPushButton (icons->loadIcon ("up", KIcon::Small),
        i18n ("Move &up"), this);
  btdown = new KPushButton (icons->loadIcon ("down", KIcon::Small),
        i18n ("Move &down"), this);

  //add widgets to layout
  layout->setSpacing (10);
  layout->setRowStretch (4, 10);
  layout->addMultiCellWidget (listbox, 0, 4, 0, 0);
  layout->addWidget (btadd, 0, 1);
  layout->addWidget (btdel, 1, 1);
  layout->addWidget (btup, 2, 1);
  layout->addWidget (btdown, 3, 1);
  
  //establish connections
  connect (btadd, SIGNAL (clicked ()), this, SLOT (addEntry ()));
  connect (btdel, SIGNAL (clicked ()), this, SLOT (removeEntry ()));
  connect (btup, SIGNAL (clicked ()), this, SLOT (moveEntryUp ()));
  connect (btdown, SIGNAL (clicked ()), this, SLOT (moveEntryDown ()));
  
  //update our contents
  update ();
}

cDirList::~cDirList ()
{

}

void cDirList::setDirList (const QStringList &dlist)
{
  dirlist = dlist;
  update ();
}

void cDirList::addEntry ()
{
  QString dirName = KFileDialog::getExistingDirectory (QString::null, this, i18n ("Choose sound directory"));
  if (dirName != QString::null)
  {
    dirlist.append (dirName);
    update();
  }
}

void cDirList::removeEntry ()
{
  int item = listbox->currentItem ();
  if (item == -1)  //nothing selected
    return;
  //find it
  QStringList::iterator it = dirlist.at (item);
  //kill it
  dirlist.erase (it);
  update ();    
}

void cDirList::moveEntryUp ()
{
  int item = listbox->currentItem ();
  if (item == -1)  //nothing selected
    return;
  if (item == 0)  //first item
    return;
  QStringList::iterator it = dirlist.at (item);
  QString text = *it;
  //it2 will point at previous item
  QStringList::iterator it2 = it;
  it2--;
  //erase that item
  dirlist.erase (it);
  //and insert it before previous item
  dirlist.insert (it2, text);
  update ();
  listbox->setCurrentItem (item - 1);
}

void cDirList::moveEntryDown ()
{
  int item = listbox->currentItem ();
  if (item == -1)  //nothing selected
    return;
  if (item == dirlist.count() - 1) //last item
    return;
  QStringList::iterator it = dirlist.at (item);
  QString text = *it;
  //erase that item, make it point to next item
  it = dirlist.erase (it);
  //and insert it after that item
  dirlist.insert (++it, text);
  update ();
  listbox->setCurrentItem (item + 1);
}

void cDirList::update ()
{
  int item = listbox->currentItem ();
  listbox->clear ();
  listbox->insertStringList (dirlist);
  if (item != -1)
    listbox->setCurrentItem (item);
}
